"""
Tools for development for end user:
Turbo: 2 or 3 line NN class set up; creates a appropriate NN based on data size and structure.
Format-Data: Formats data for NN to use (using pyndb)
Img-Matrix: converts a image to a 3d convolution matrix (options for RGB and Grayscale)
HelpIHaveNoIdeaWhatImDoing: documentation and a start-up guide
Extract-Verification-Data: extracts verification data from a CSV file (more data formats soon)
"""

